# Query State Lib

### Install 
 
> pip3 install QueryStateLib

### Example do query state batch at client

* [Example used](_test/test_client_querier.py)

Github : https://github.com/thanhnv2303/QueryStateLib

